import random

def random_get(dic: dict[str, str], str_key: str, mode:str = "static"):
    if mode == "static":
        count = sum([ord(c) for c in str_key])
        keys = list(dic.keys())
        return dic[keys[count % len(keys)]]
    else:
        keys = list(dic.keys())
        return dic[random.choice(keys)]

opening: dict[str, str] = {}

# opening["parrot"] = r"""
#                            .    
#                           | \/| 
#                           ) )|/|
#                     _----. /.'.'
# .-._________..      .' @ _\  .' 
# '.._______.   '.   /    (_| .') 
#   '._____.  /   '-/      | _.'  
#    '.______ (         ) ) \     
#      '..____ '._       )  )     
#         .' __.--\  , ,  // ((   
#         '.'     |  \/   (_.'(   
#                 '   \ .'        
#                  \   (          
#                   \   '.        
#                    \ \ '.)      
#                     '-'-'       
# """

opening["estuda"] = r"""
▄▖         ▐▘      ▘                 ▐▘▘▜ ▗       ▄▖
▌ ▛▌▛▛▌▛▌  ▜▘▌▌▛▌▛▘▌▛▌▛▌▀▌▛▛▌  ▛▌▛▘  ▜▘▌▐ ▜▘▛▘▛▌▛▘▗▘
▙▖▙▌▌▌▌▙▌  ▐ ▙▌▌▌▙▖▌▙▌▌▌█▌▌▌▌  ▙▌▄▌  ▐ ▌▐▖▐▖▌ ▙▌▄▌▗ 
                                                    
Os botões de 1 a 4 habilitam os filtros de exibição.
- Gráficos: mostra os gráficos de acompanhamento.
- Trilhas : mostra a barra lateral de trilhas de habilidades.
- Tópicos : mostra as missões (recomendadas ou todas).
- Tarefas : esconde as atividades já concluídas.
▄▖         ▐▘      ▘                ▗   ▄▖
▌ ▛▌▛▛▌▛▌  ▜▘▌▌▛▌▛▘▌▛▌▛▌▀▌  ▀▌  ▛▌▛▌▜▘▀▌▗▘
▙▖▙▌▌▌▌▙▌  ▐ ▙▌▌▌▙▖▌▙▌▌▌█▌  █▌  ▌▌▙▌▐▖█▌▗ 
                                          
- Após fazer ou refazer uma atividade, você usa o comando de pontuar,
usando o 'p' ou o '.', e informe como fez a atividade.
       ⢀⣠⣤⣴⡾⠻⢶⣤⡀ 
     ⢀⣶⠟⠉⠉    ⠉⢷⡄  - Quanto da atividade foi entregue?
   ⠉⢿⣿⣿⣿⠏⠈⢿⣿⣿⣿⡿⢟⣿    - Se houver testes, isso será calculado automaticamente
    ⢸⡏ ⢠⣀ ⢀⡤   ⢨⣿  - Quanto conseguiu fazer antes de consultar ajuda?
    ⠸⣿⡀ ⠉⠉⠉  ⢀⣠⡾⠃  - Se utilizou alguma ajuda, qual foi?
     ⠈⠻⠷⠶⣶⡶⠾⠿⠛⠉      - Humana? Quem?
 ⢀⡀     ⢀⣿           - IA? Qual? Como?
⠿⢿⣧⡀    ⣸⣟           - Guiada seguindo aula ou vídeo?
  ⠘⢿⡄ ⣠⡾⢻⣿⣄          - Outros? Pesquisando na documentação ou exemplos?
    ⢿⣴⡟ ⢸⡏⠹⣧       - Qual tempo estimado em minutos de estudo + implementação?
    ⠈⠛  ⢸⣟ ⠹⣧    
- Você pode e deve refazer a atividade do zero quantas vezes quiser e
reavaliar e melhorar sua nota.


"""[1:]

# opening["alien4"] = r"""
#             ______              ______
#            /___   \___\ || /___/   ___\
#           //\]/\ ___  \\||//  ___ /\[/\\
#           \\/[\//  _)   \/   (_  \\/]\//
#            \___/ _/   o    o   \_ \___/
#                _/                \_
#               //'VvvvvvvvvvvvvvvV'\\
#              ( \.'^^^^^^^^^^^^^^'./ )
#               \____   . .. .   ____/
#    ________        \ . .''. . /        ________
#   /______  \________)________(________/ _______\
#  /|       \ \  Estuda seu miserável  / /       |\
# (\|____   / /                        \ \   ____|/)
# """

# opening["alien5"] = r"""
#                    ⢀⡀⠤⠤⠤⠄ ⠒⠢⣄    
#                 ⡠⠐⢈⠄        ⢸⠓⠄  
#               ⠐⠈⠠⠊         ⡠⠊ ⠈⢂ 
#             ⢀⠊ ⡐⠁        ⢠⢊⠔⠈   ⠆
#            ⣠⡃ ⢰    ⢀⡠⠄⠐⠒ ⢸⢜⠄     
#           ⡐⣁⡑ ⠘  ⢀⠔⢁⣀⣤⣤⣤⣒⣤ ⠈    ⡄
#           ⢫⣿⢧ ⢸  ⣡⣶⣯⠭⢄⣀⣼⡏⠁⢀⡤   ⢐⠁
#           ⢠⢿⣾⣧⠈ ⢠⣿⣿⣗⢢⣤⣿⡿⢋ ⡏    ⡌ 
#    Gosto  ⠘⠳⠙⠻  ⠰⠿⠟⠛⠻⢍⠫⠒⠁⡰   ⢀⠜  
#     de    ⠘⢄          ⢀⠠⢊ ⡇⢠⠒⠁   
#    comer    ⠈⢦⠂    ⢠⠊⠁ ⢀⠄ ⡇⢸     
#  cérebros    ⠘⢄⡄⢤⢄ ⠘⡄  ⡀⠄⢊⡅⡆⢆    
#     de         ⢊   ⠈⢁⠴⠅⣀⣀⠘⢣⠠⠈⠢⢀  
#   alunos       ⠈⠢⢄⣀⡠⠊  ⠈⢣ ⠈⠃⠡  ⠉⠐
# preguiçosos             ⠰⠇  ⠐⡑⠤⢀ 
# """

intro: dict[str, str] = {}

intro["elephant"] = r"""
        ⣀⣀                                                                      
      ⣰⣿⣿⣿⣿⣦⣀⣀⣀           ↲ -> avalia usando os testes cadastrados no cases.tio 
      ⢿⣿⠟⠋⠉    ⠉⠑⠢⣄⡀      r -> compila e (r)oda fazendo entrada de dados manual 
     ⢠⠞⠁           ⠙⢿⣿⣿⣦⡀                                                       
 ⣀  ⢀⡏ ⢀⣴⣶⣶⡄         ⢻⣿⣿⠇ TAB -> Muda o arquivo PRINCIPAL se múltiplos arquivos 
⣾⣿⣿⣦⣼⡀ ⢺⣿⣿⡿⠃    ⣠⣤⣄  ⠈⡿⠋                                                        
⢿⣿⣿⣿⣿⣇ ⠤⠌⠁ ⡀⢲⡶⠄⢸⣏⣿⣿   ⡇   d -> muda o modo (d)iff de vertical para horizontal   
⠈⢿⣿⣿⣿⣿⣷⣄⡀  ⠈⠉⠓⠂ ⠙⠛⠛⠠ ⡸⠁   u -> trava a avaliação em (u)m único caso de teste    
  ⠻⣿⣿⣿⣿⣿⣿⣷⣦⣄⣀    ⠑ ⣠⠞⠁    t -> define o limite de (t)empo para execução         
   ⢸⡏⠉⠛⠛⠛⠿⠿⣿⣿⣿⣿⣿⣿⣿⣿⡄                                                            
   ⠸        ⠈⠉⠛⢿⣿⣿⣿⣿⡄     esquerda direita -> muda o teste apresentado          
"""

compilling_image: dict[str, str] = {}

executing_image: str = r"""
███████╗██╗  ██╗███████╗ ██████╗██╗   ██╗████████╗ █████╗ ███╗   ██╗██████╗  ██████╗ 
██╔════╝╚██╗██╔╝██╔════╝██╔════╝██║   ██║╚══██╔══╝██╔══██╗████╗  ██║██╔══██╗██╔═══██╗
█████╗   ╚███╔╝ █████╗  ██║     ██║   ██║   ██║   ███████║██╔██╗ ██║██║  ██║██║   ██║
██╔══╝   ██╔██╗ ██╔══╝  ██║     ██║   ██║   ██║   ██╔══██║██║╚██╗██║██║  ██║██║   ██║
███████╗██╔╝ ██╗███████╗╚██████╗╚██████╔╝   ██║   ██║  ██║██║ ╚████║██████╔╝╚██████╔╝
╚══════╝╚═╝  ╚═╝╚══════╝ ╚═════╝ ╚═════╝    ╚═╝   ╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝  ╚═════╝ 
"""

compilling_image["computer"] = r"""
 ██████╗ ██████╗ ███╗   ███╗██████╗ ██╗██╗      █████╗ ███╗   ██╗██████╗  ██████╗ 
██╔════╝██╔═══██╗████╗ ████║██╔══██╗██║██║     ██╔══██╗████╗  ██║██╔══██╗██╔═══██╗
██║     ██║   ██║██╔████╔██║██████╔╝██║██║     ███████║██╔██╗ ██║██║  ██║██║   ██║
██║     ██║   ██║██║╚██╔╝██║██╔═══╝ ██║██║     ██╔══██║██║╚██╗██║██║  ██║██║   ██║
╚██████╗╚██████╔╝██║ ╚═╝ ██║██║     ██║███████╗██║  ██║██║ ╚████║██████╔╝╚██████╔╝
 ╚═════╝ ╚═════╝ ╚═╝     ╚═╝╚═╝     ╚═╝╚══════╝╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝  ╚═════╝ 
"""

success_image: dict[str, str] = {}
success_image["success"] = r"""
███████╗██╗   ██╗ ██████╗███████╗███████╗███████╗ ██████╗ 
██╔════╝██║   ██║██╔════╝██╔════╝██╔════╝██╔════╝██╔═══██╗
███████╗██║   ██║██║     █████╗  ███████╗███████╗██║   ██║
╚════██║██║   ██║██║     ██╔══╝  ╚════██║╚════██║██║   ██║
███████║╚██████╔╝╚██████╗███████╗███████║███████║╚██████╔╝
╚══════╝ ╚═════╝  ╚═════╝╚══════╝╚══════╝╚══════╝ ╚═════╝ 
"""

images: dict[str, str] = {}

images["pink"] = r"""
Programando assim, você vai dominar o mundo!
                 /`.    /`.                       
                f   \  ,f  \                      
                |    \/-`\  \                     
                i.  _\';.,X j                     
                 `:_\ (  \ \',-.                  
                   .'"`\ a\eY' )               _,.
                   `._"\`-' `-/            .-;'  |
                     /;-`._.-';\.        ,',"    |
                   .'/   "'   | `\.-'""-/ /      j
                 ,/ /         i,-"        (  ,/  /
              .-' .f         .'            `"/  / 
             / ,,/ffj\      /          .-"`.'-.'  
            / /_\`--//)     \ ,--._ .-'_,-'; /    
           f  ".-"-._;'      `._ _.,-i; /_; /     
           `.,'   |; \          \`\_,/-'  \'      
            .'    l \ `.        /"\ _ \`  j       
            f      : `-'        `._;."/`-'        
"""

images["batman"] = r"""
Não é o que sou por dentro, é o que eu faço que me define.
                     .  .          
                     |\_|\         
                     | a_a\        
                     | | "]        
                 ____| '-\___      
                /.----.___.-'\     
               //        _    \    
              //   .-. (~v~) /|    
             |'|  /\:  .--  / \    
            // |-/  \_/____/\/~|   
           |/  \ |  []_|_|_] \ |   
           | \  | \ |___   _\ ]_}  
           | |  '-' /   '.'  |     
           | |     /    /|:  |     
           | |     |   / |:  /\    
           | |     /  /  |  /  \   
           | |    |  /  /  |    \  
           \ |    |/\/  |/|/\    \ 
            \|\ |\|  |  | / /\/\__\
             \ \| | /   | |__      
                  / |   |____)     
                  |_/              
"""


images["vegeta"] = r"""
O miserável é um gênio!
    ⢨⠊ ⢀⢀   ⠈⠺⡵⡱   ⢠⠃ ⡀         ⡘⢰⡁⠉⠊⠙⢎⣆    ⢩⢀⠜   
   ⢠⠃  ⢸⢸⡀    ⠘⢷⡡  ⠎ ⢰⣧  ⠈⡆       ⠈⣐⢤⣀⣀⢙⠦    ⡇    
  ⢀⠃   ⡌⢸⠃   ⢀  ⠑⢧⡸ ⢀⣿⢻⡀  ⣻     ⣠⡴⠛⠉   ⠑⢝⣦   ⢰⠠⠁  
  ⠌   ⡘⣖⣄⢃   ⠈⢦⡀ ⡜⡇ ⣼⠃⠈⢷⣶⢿⠟   ⢠⠞⠁ ⣀⠄⠂⣶⣶⣦⠆⠋⠓ ⢀⣀⡇   
⠡⡀⡇ ⢰⣧⢱⠊⠘⡈⠄  ⡀⠘⣿⢦⣡⢡⢰⡇⢀⠤⠊⡡⠃  ⢀⡴⠁⢀⠔⠊  ⢠⣿⠟⠁ ⢀ ⢀⠾⣤⣀  ⡠
⡀⠱⡇ ⡆⢃   ⠃   ⣧⣀⣹⡄⠙⡾⡏ ⡌⣠⡾⠁  ⣠⠊⢠⠔⠁    ⣸⡏   ⢨⣪⡄⢻⣥⠫⡳⢊⣴
  ⢡⢠ ⢸⡆ ⣀    ⠈⣛⢛⣁⣀⠘⣧⣀⢱⡿  ⢀⡔⢁⢔⠕⠉⠐⣄⣠⠤⠶⠛⠁⢀⣀  ⠉⠁⠈⠷⣞⠔⡕⣿
⢄⡀⠘⢸ ⣘⠇        ⠉⠐⠤⡑⢎⡉⢨⠁ ⣠⢏⠔⠁⠘⣤⠴⢊⣡⣤⠴⠖⠒⠻⠧⣐⠓    ⠈ ⡜ ⠇
⠤⡈⠑⠇⠡⣻⢠⠊⠉⠉⠉⠑⠒⠤⣀   ⠈⣾⣄⢘⣫⣜⠮⢿⣆⡴⢊⢥⡪⠛⠉    ⢀⠄⠂⠁      ⢧⡀⠈
⠁⠈⠑⠼⣀⣁⣇ ⣴⡉⠉⠉ ⠒⡢⠌⣐⡂⠶⣘⢾⡾⠿⢅ ⣠⣶⡿⠓⠁⢠⠖⣦⡄   ⠊         ⠈⢎⢳
    ⠉⣇⣿⢜⠙⢷⡄   ⣄⣠⠼⢶⡛⣡⢴ ⢀⠛⠱⡀    ⢀⠎ ⠁            ⢠⡋⠮⡈
  ⢀⣖⠂⢽⡈ ⠈⠑⠻⡦⠖⢋⣁⡴⠴⠊⣉⡠⢻⡖⠪⢄⡀⢈⠆  ⢠⠊⢠             ⢀⠤⡵⢤⣃
  ⠸⢠⡯⣖⢵⡀  ⣠⣤⠮⠋⠁     ⠸⣌⢆⢱⡾⠃⢀⠠⠔⠁⣀⢸     ⡄       ⡸⠚⡸⠈⠁
⠤⢀⣀⢇⢡⠸⡗⢔⡄⠸⠊           ⠉⡩⠔⢉⡠⠔⠂⠉⢀⠆            ⢠⢁⠎⢀⡠⠔
   ⠘⡌⢦⡃⣎⠘⡄        ⠠⡟⠠⡐⣋⠤ ⣀⠤⠐⠂⠉⠁             ⡸⢉⠉⠁  
⠤   ⠰⡀⠈⠻⡤⠚⢄  ⢠       ⠈⠂⠒⠉                  ⢠⠃⢸ ⢀⠤⠊
⣀    ⠘⠢⡑⢽⡬⢽⢆ ⠈           ⣠⣤⡶⠟⣉⣉⢢          ⢀⠇ ⠈⡖⠓⠒⠂
 ⢈⣑⣒⡤⠄ ⠈⠑⠥⣈⠙⠧           ⢰⣁⠔⠊⠁        ⡜   ⣠⡻   ⠇⠐⡔⣡
⠉⠉⠁ ⠒⠒⠒⠒ ⠤⠤⠍⣒⡗⢄⡀        ⠈           ⡸  ⢠⡞⢡⠃   ⢸ ⠸⣡
            ⢠  ⠈⣶⢄⡀                ⡰⠁⣠⡔⠉ ⡎    ⢸  ⠃
         ⢠⠇⣀⢼   ⢉⡄⠈⠐⠤⣀         ⢀⡀ ⡜⡡⣾⠃  ⠸      ⡧⢄⡈
       ⣀⠤⠚⠉ ⡆   ⠈⡵⢄⡀  ⠙⠂⠄⣀⡀⠤⠊⠉⢀⣀⣠⡴⢿⣟⠞  ⢀⠇      ⡗⠢⢌
"""



images["esqueleto"] = r"""
Você venceu o desafio, mas não a guerra!
Espero você no próximo nível!
                              _.--""-._                     
  .                         ."         ".                   
 / \    ,^.         /(     Y             |      )\          
/   `---. |--'\    (  \__..'--   -   -- -'""-.-'  )         
|        :|    `>   '.     l_..-------.._l      .'          
|      __l;__ .'      "-.__.||_.-'v'-._||`"----"            
 \  .-' | |  `              l._       _.'                   
  \/    | |                   l`^^'^^'j                     
        | |                _   \_____/     _                
        j |               l `--__)-'(__.--' |               
        | |               | /`---``-----'"1 |  ,-----.      
        | |               )/  `--' '---'   \'-'  ___  `-.   
        | |              //  `-'  '`----'  /  ,-'   I`.  \  
      _ L |_            //  `-.-.'`-----' /  /  |   |  `. \ 
     '._' / \         _/(   `/   )- ---' ;  /__.J   L.__.\ :
      `._;/7(-.......'  /        ) (     |  |            | |
      `._;l _'--------_/        )-'/     :  |___.    _._./ ;
"""

images["coiote"] = r"""
Você fez essa questão muito rápido, da próxima vez
vou aumentar a dificuldade!
                      _                                   
                     : \                                  
                     ;\ \_                   _            
                     ;@: ~:              _,-;@)           
                     ;@: ;~:          _,' _,'@;           
                     ;@;  ;~;      ,-'  _,@@@,'           
                    |@(     ;      ) ,-'@@@-;             
                    ;@;   |~~(   _/ /@@@@@@/              
                    \@\   ; _/ _/ /@@@@@@;~               
                     \@\   /  / ,'@@@,-'~                 
                       \\  (  ) :@@(~                     
                    ___ )-'~~~~`--/ ___                   
                   (   `--_    _,--'   )                  
                  (~`- ___ \  / ___ -'~)                  
                 __~\_(   \_~~_/   )_/~__                 
 /\ /\ /\     ,-'~~~~~`-._ 0\/0 _,-'~~~~~`-.              
| |:  ::|    ;     ______ `----'  ______    :             
| `'  `'|    ;    {      \   ~   /      }   |             
 \_   _/     `-._      ,-,' ~~  `.-.      _,'        |\   
   \ /_          `----' ,'       `, `----'           : \  
   |_( )                `-._/#\_,-'                  :  ) 
 ,-'  ~)           _,--./  (###)__                   :  : 
 (~~~~_)          /       ; `-'   `--,               |  ; 
"""

images["piupiu"] = r"""
Eu acho que eu vi um programador!
                 $                
              $  $   $$           
              $ $$ $$             
         $$$$      $$$$$$         
       $$                $$       
     $$        $$          $$     
   $$                        $$   
  $$                          $$  
  $                           $ $ 
 $                $             $ 
 $             $$$$              $
 $            $$ $           $   $
 $          $$$$$$       $$$$    $
 $         $$$$$$$      $$  $    $
  $        $$$$$ $     $$$$$$   $ 
  $$       $     $    $$$$$$   $$ 
   $$      $    $    $$$$     $   
    $      $   $     $       $    
    $      $$$$         $  $$     
    $$               $$$  $       
     $$$       $$$$$      $       
        $$$     $$       $$       
            $$     $$$$$$         
          $$      $$ $            
       $$$$        $ $$           
         $  $$     $   $          
    $$$$$$ $       $  $           
  $$   $$$$ $      $   $$$$$$$    
  $$      $$$$     $ $$     $$    
  $          $$$$$$$$         $   
   $$         $   $          $    
    $$$$$$$$$$$   $$$$$$$$$$$ ~*  
"""

images["saitama"] = r"""
Se garantiu
        ⣠⣴⣶⡋⠉⠙⠒⢤⡀     ⢠⠖⠉⠉⠙⠢⡄ 
      ⢀⣼⣟⡒⠒     ⠙⣆   ⢠⠃     ⠹⡄
      ⣼⠷⠖        ⠘⡆  ⡇       ⢷
      ⣷⡒  ⢐⣒⣒⡒ ⣐⣒⣒⣧  ⡇ ⢠⢤⢠⡠  ⢸
     ⢰⣛⣟⣂ ⠘⠤⠬⠃⠰⠑⠥⠊⣿ ⢴⠃ ⠘⠚⠘⠑⠐ ⢸
     ⢸⣿⡿⠤     ⢀⡆  ⣿  ⡇       ⣸
     ⠈⠿⣯⡭    ⢀⣀   ⡟  ⢸      ⢠⠏
       ⠈⢯⡥⠄      ⡼⠁   ⠳⢄⣀⣀⣀⡴⠃ 
         ⢱⡦⣄⣀⣀⣀⣠⠞⠁      ⠈⠉    
       ⢀⣤⣾⠛⠃   ⢹⠳⡶⣤⡤⣄         
    ⣠⢴⣿⣿⣿⡟⡷⢄⣀⣀⣀⡼⠳⡹⣿⣷⠞⣳        
   ⢰⡯⠭⠹⡟⠿⠧⠷⣄⣀⣟⠛⣦⠔⠋⠛⠛⠋⠙⡆       
  ⢸⣿⠭⠉ ⢠⣤   ⠘⡷⣵⢻    ⣼ ⣇       
  ⡇⣿⠍⠁ ⢸⣗⠂   ⣧⣿⣼    ⣯ ⢸  
"""

images["cool"] = r"""
Essa foi show de bola!
       ⢀⣠⣤⣴⡾⠻⢶⣤⡀ 
     ⢀⣶⠟⠉⠉    ⠉⢷⡄
   ⠉⢿⣿⣿⣿⠏⠈⢿⣿⣿⣿⡿⢟⣿
    ⢸⡏ ⢠⣀ ⢀⡤   ⢨⣿
    ⠸⣿⡀ ⠉⠉⠉  ⢀⣠⡾⠃
     ⠈⠻⠷⠶⣶⡶⠾⠿⠛⠉  
 ⢀⡀     ⢀⣿       
⠿⢿⣧⡀    ⣸⣟       
  ⠘⢿⡄ ⣠⡾⢻⣿⣄      
    ⢿⣴⡟ ⢸⡏⠹⣧     
    ⠈⠛  ⢸⣟ ⠹⣧    
"""

images["among"] = r"""
Sossegue, você não é um importor
           ⣠⣤⣤⣤⣤⣤⣶⣦⣤⣄⡀         
        ⢀⣴⣿⡿⠛⠉⠙⠛⠛⠛⠛⠻⢿⣿⣷⣤⡀      
        ⣼⣿⠋       ⢀⣀⣀⠈⢻⣿⣿⡄     
       ⣸⣿⡏   ⣠⣶⣾⣿⣿⣿⠿⠿⠿⢿⣿⣿⣿⣄    
       ⣿⣿⠁  ⢰⣿⣿⣯⠁       ⠈⠙⢿⣷⡄  
  ⣀⣤⣴⣶⣶⣿⡟   ⢸⣿⣿⣿⣆          ⣿⣷  
 ⢰⣿⡟⠋⠉⣹⣿⡇   ⠘⣿⣿⣿⣿⣷⣦⣤⣤⣤⣶⣶⣶⣶⣿⣿⣿  
 ⢸⣿⡇  ⣿⣿⡇    ⠹⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠃  
 ⣸⣿⡇  ⣿⣿⡇     ⠉⠻⠿⣿⣿⣿⣿⡿⠿⠿⠛⢻⣿⡇   
 ⣿⣿⠁  ⣿⣿⡇                ⢸⣿⣧   
 ⣿⣿   ⣿⣿⡇                ⢸⣿⣿   
 ⣿⣿   ⣿⣿⡇                ⢸⣿⣿   
 ⢿⣿⡆  ⣿⣿⡇                ⢸⣿⡇   
 ⠸⣿⣧⡀ ⣿⣿⡇                ⣿⣿⠃   
  ⠛⢿⣿⣿⣿⣿⣇     ⣰⣿⣿⣷⣶⣶⣶⣶⠶ ⢠⣿⣿    
       ⣿⣿     ⣿⣿⡇ ⣽⣿⡏⠁  ⢸⣿⡇    
       ⣿⣿     ⣿⣿⡇ ⢹⣿⡆   ⣸⣿⠇    
       ⢿⣿⣦⣄⣀⣠⣴⣿⣿⠁ ⠈⠻⣿⣿⣿⣿⡿⠏     
       ⠈⠛⠻⠿⠿⠿⠿⠋⠁               
"""

images["heart"] = r"""
O código ficou lindo dessa vez!
     ⣀⣀⣀⡀          ⣀⣠⣠⣴⣦⣤⣤⣄⣀   
  ⣰⣼⣿⣯⢭⣿⣿⣿⣻⣶⣤⡀  ⢀⣠⣾⣿⣿⣾⣿⣿⣿⣽⣿⣿⣻⣦⡀
 ⣰⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣧⣴⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿
⢀⣿⣿⣿⣿⣿⣿⣿⣿⡟⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡟
⢸⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⢡⠊⢻⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡇
⢸⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⠇⠎⠠⠐⡉⢉⠁⠘⣭⣿⣿⣿⣿⣿⣿⣿⡿ 
⠈⢿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠟⠋⠈⠄⡁⠂⢀⠂⡬⣾⣿⣿⣿⣿⣿⣿⣿⣿⠁ 
 ⠈⢿⣿⣿⣿⣿⣿⣶⣤⣖⡂⠌⠐⠠⠐⢨⢀⠄⠘⢜⢿⣿⣿⣿⣿⣿⣿⠃  
   ⠹⣿⣿⣿⣿⣿⣿⣿⣿⠆⠁⢂⠅⣒⡈⠤⠈⡈ ⠻⣿⣿⣿⡿⠃   
    ⠙⢿⣿⣿⣿⣿⣿⣿⣄⡦⣠⣾⣿⣿⣿⣷⣾⣤⣗⣹⣿⡟     
      ⠘⠿⣿⣿⣿⣿⣴⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⠏      
        ⠻⢿⣟⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠏       
          ⠘⠻⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠁        
             ⠙⠿⢿⣿⣿⣿⡿⠋          
"""

images["pikachu"] = r"""
        Picapi!          
⢀⣠⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿    ⣠⣤⣶⣶
⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿   ⢰⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣧⣀⣀⣾⣿⣿⣿⣿
⣿⣿⣿⣿⣿⡏⠉⠛⢿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⣿
⣿⣿⣿⣿⣿⣿   ⠈⠛⢿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⠿⠛⠉⠁ ⣿
⣿⣿⣿⣿⣿⣿⣧⡀    ⠙⠿⠿⠿⠻⠿⠿⠟⠿⠛⠉     ⣸⣿
⣿⣿⣿⣿⣿⣿⣿⣷⣄ ⡀               ⢀⣴⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⣿⠏              ⠠⣴⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⡟  ⢰⣹⡆      ⣭⣷   ⠸⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⠃  ⠈⠉  ⠤⠄   ⠉⠁    ⢿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⢾⣿⣷    ⡠⠤⢄   ⠠⣿⣿⣷ ⢸⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⡀⠉     ⢄ ⢀    ⠉⠉⠁  ⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⣧       ⠈          ⢹⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⣿⠃                 ⢸⣿⣿
"""

images["yoda"] = r"""
Que a força esteja com você                               
 ⢀⣠⣄⣀⣀⣀               ⣀⣤⣴⣶⡾⠿⠿⠿⠿⢷⣶⣦⣤⣀⡀                     
⢰⣿⡟⠛⠛⠛⠻⠿⠿⢿⣶⣶⣦⣤⣤⣀⣀⡀⣀⣴⣾⡿⠟⠋⠉        ⠉⠙⠻⢿⣷⣦⣀         ⢀⣀⣀⣀⣀⣀⣀⣀⡀
 ⠻⣿⣦⡀ ⠉⠓⠶⢦⣄⣀⠉⠉⠛⠛⠻⠿⠟⠋⠁   ⣤⡀  ⢠   ⣠    ⠈⠙⠻⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠟⠛⠛⢻⣿
  ⠈⠻⣿⣦    ⠈⠙⠻⢷⣶⣤⡀    ⢀⣀⡀ ⠙⢷⡀⠸⡇ ⣰⠇ ⢀⣀⣀      ⣀⣠⣤⣤⣶⡶⠶⠶⠒⠂  ⣠⣾⠟
    ⠈⢿⣷⡀      ⠈⢻⣿⡄⣠⣴⣿⣯⣭⣽⣷⣆ ⠁    ⢠⣾⣿⣿⣿⣿⣦⡀ ⣠⣾⠟⠋⠁       ⣠⣾⡟⠁ 
     ⠈⢻⣷⣄       ⣿⡗⢻⣿⣧⣽⣿⣿⣿⣧  ⣀⣀ ⢠⣿⣧⣼⣿⣿⣿⣿⠗⠰⣿⠃        ⣠⣾⡿⠋   
       ⠙⢿⣶⣄⡀    ⠸⠃⠈⠻⣿⣿⣿⣿⣿⡿⠃⠾⣥⡬⠗⠸⣿⣿⣿⣿⣿⡿⠛ ⢀⡟      ⣀⣠⣾⡿⠋     
         ⠉⠛⠿⣷⣶⣤⣤⣄⣰⣄  ⠉⠉⠉⠁ ⢀⣀⣠⣄⣀⡀ ⠉⠉⠉  ⢀⣠⣾⣥⣤⣤⣤⣶⣶⡿⠿⠛⠉       
             ⠈⠉⢻⣿⠛⢿⣷⣦⣤⣴⣶⣶⣦⣤⣤⣤⣤⣬⣥⡴⠶⠾⠿⠿⠿⠿⠛⢛⣿⣿⣿⣯⡉⠁           
               ⠈⣿⣧⡀⠈⠉ ⠈⠁⣾⠛⠉⠉          ⣀⣴⣿⠟⠉⣹⣿⣇            
               ⢀⣸⣿⣿⣦⣀   ⢻⡀       ⢀⣠⣤⣶⣿⠋⣿⠛⠃ ⣈⣿⣿            
               ⣿⡿⢿⡀⠈⢹⡿⠶⣶⣼⡇ ⢀⣀⣀⣤⣴⣾⠟⠋⣡⣿⡟ ⢻⣶⠶⣿⣿⠛⠋            
              ⠘⣿⣷⡈⢿⣦⣸⠇⢀⡿⠿⠿⡿⠿⠿⣿⠛⠋⠁ ⣴⠟⣿⣧⡀⠈⢁⣰⣿⠏              
               ⢸⣿⢻⣦⣈⣽⣀⣾⠃ ⢸⡇ ⢸⡇ ⢀⣠⡾⠋⢰⣿⣿⣿⣿⡿⠟⠋               
               ⠘⠿⢿⣿⣿⡟⠛⠃  ⣾  ⢸⡇⠐⠿⠋  ⣿⢻⣿⣿                   
                  ⢸⣿⠁⢀⡴⠋ ⣿  ⢸⠇     ⠁⢸⣿⣿                   
                 ⢀⣿⡿⠟⠋   ⣿  ⣸       ⢸⣿⣿                   
                 ⢸⣿⣁⣀    ⣿⡀ ⣿      ⢀⣈⣿⣿                   
                 ⠘⠛⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠟⠛⠋                   
"""

images["vader"] = r"""
Sua falta de fé é perturbadora.
                 ⢀⣀⡀   ⢀⣀               
            ⣠⣤⣶⣾⣿⡉⢤⣍⡓⢶⣶⣦⣤⣉⠒⠤⡀           
         ⢀⣴⣿⣿⣿⣿⣿⣿⣷⡀⠙⣿⣷⣌⠻⣿⣿⣿⣶⣌⢳⡀         
        ⣰⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣄⠈⢿⣿⡆⠹⣿⣿⣿⣿⣷⣿⡀        
       ⣰⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣷⣄⠹⣿⡄⢻⣿⣿⣿⣿⣿⣧        
      ⢠⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠿⠿⣿⣿⣷⣽⣷⢸⣿⡿⣿⡿⠿⠿⣆       
      ⣼⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡄   ⠐⠾⢭⣭⡼⠟⠃⣤⡆⠘⢟⢺⣦⡀     
      ⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⢛⣥⣶⠾⠿⠛⠳⠶⢬⡁  ⠘⣃⠤⠤⠤⢍⠻⡄    
      ⣿⣿⣿⣿⣿⣿⣿⡿⣫⣾⡿⢋⣥⣶⣿⠿⢿⣿⣿⣿⠩⠭⢽⣷⡾⢿⣿⣦⢱⡹⡀   
      ⣿⣿⣿⣿⣿⣿⡟⠈⠛⠏⠰⢿⣿⣿⣧⣤⣼⣿⣿⣿⡏⠩⠽⣿⣀⣼⣿⣿⢻⣷⢡   
     ⢰⣿⣿⣿⣿⣿⣿⢁⣿⣷⣦⡀ ⠉⠙⠛⠛⠛⠋⠁⠙⢻⡆ ⢌⣉⠉⠉ ⠸⣿⣇⠆  
    ⢀⣾⣿⣿⣿⣿⣿⡇⢸⣿⣿⣿⣿⠷⣄⢠⣶⣾⣿⣿⣿⣿⣿⠁  ⢿⣿⣿⣿⣷⠈⣿⠸⡀ 
    ⣼⣿⣿⣿⣿⣿⣿ ⣌⡛⠿⣿⣿ ⠈⢧⢿⣿⡿⠟⠋⠉⣠⣤⣤⣤⣄⠙⢿⣿⠏⣰⣿⡇⢇ 
   ⣼⣿⣿⣿⣿⣿⣿⡇⢸⣿⣿⣶⣤⣙⠣⢀⠈⠘⠏  ⢀⣴⢹⡏⢻⡏⣿⣷⣄⠉⢸⣿⣿⣷⠸⡄
  ⣸⣿⣿⣿⣿⣿⣿⣿⠁⣾⣟⣛⠛⠛⠻⠿⠶⠬⠔ ⣠⡶⠋⠿⠈⠷⠸⠇⠻⠏⠻⠆⣀⢿⣿⣿⡄⢇
 ⢰⣿⣿⣿⣿⠿⠿⠛⠋⣰⣿⣿⣿⣿⠿⠿⠿⠒⠒⠂ ⢨⡤⢶⣶⣶⣶⣶⣶⣶⣶⣶⠆⠃⣀⣿⣿⡇⣸
⢀⣿⣿⠿⠋⣡⣤⣶⣾⣿⣿⣿⡟⠁ ⣠⣤⣴⣶⣶⣾⣿⣿⣷⡈⢿⣿⣿⣿⣿⠿⠛⣡⣴⣿⣿⣿⣿⠟⠁
⣼⠋⢁⣴⣿⣿⣿⣿⣿⣿⣿⣿   ⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣎⠻⠟⠋⣠⣴⣿⣿⣿⣿⠿⠋⠁  
⢿⣷⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿ ⣴ ⠻⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣧⣠⣾⣿⠿⠿⠟⠋⠁     
 ⠉⠛⠛⠿⠿⠿⢿⣿⣿⣿⣵⣾⣿⣧⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠏           
                  ⠉⠉⠉⠉⠉⠉⠉⠁              
"""

images["mario"] = r"""
Vamos lá. Nossa grande aventura começa agora!
                      ⢀⣀⣠⣤⣤⣤⣄⣀            
                   ⣠⣴⡾⣻⣿⣿⣿⣿⣯⣍⠛⠻⢷⣦⣀        
                ⢀⣴⣿⠟⢁⣾⠟⠋⣁⣀⣤⡉⠻⣷⡀ ⠙⢿⣷⣄      
       ⢀⡀      ⣰⣿⠏  ⢸⣿ ⠼⢋⣉⣈⡳⢀⣿⠃   ⠙⣿⣦⡀    
      ⢰⡿⠿⣷⡀   ⣼⣿⠃  ⣀⣤⡿⠟⠛⠋⠉⠉⠙⢛⣻⠶⣦⣄⡀ ⠘⣿⣷⡀   
⢠⣾⠟⠳⣦⣄⢸⡇ ⠈⣷⡀ ⣼⣿⡏⢀⣤⡾⢋⣵⠿⠻⢿⠋⠉⠉⢻⠟⠛⠻⣦⣝⠻⣷⣄⠸⣿⣿   
⠘⣧   ⠙⢿⣿  ⢸⣷ ⣿⣿⣧⣾⣏⡴⠛⢡⠖⢛⣲⣅  ⣴⣋⡉⠳⡄⠈⠳⢬⣿⣿⣿⡿   
 ⠘⠷⣤⣀⣀⣀⣽⡶⠛⠛⠛⢷⣿⣿⣿⣿⣏  ⡏⢰⡿⢿⣿  ⣿⠻⣿ ⡷ ⣠⣾⣿⡿⠛⠷⣦  
  ⢀⣾⠟⠉⠙⣿⣤⣄ ⢀⣾⠉ ⢹⣿⣿⣷ ⠹⡘⣷⠾⠛⠋⠉⠛⠻⢿⡴⢃⣄⣻⣿⣿⣷  ⢹⡇ 
  ⢸⡇⠈⠉⠛⢦⣿⡏ ⢸⣧ ⠈⠻⣿⡿⢣⣾⣦⣽⠃       ⣷⣾⣿⡇⠉⢿⡇ ⢀⣼⠇ 
  ⠘⣷⡠⣄⣀⣼⠇   ⠻⣷⣤⣀⣸⡇ ⠹⣿⣿⣦⣀    ⢀⣴⣿⣿⡟  ⢸⣷⣾⡿⠃  
   ⠈⠻⢦⣍⣀⣀⣀⡄ ⣰⣿⡿⠿⢿⣇  ⠉⠛⠻⣿⣿⡷⠾⣿⣿⡿⠉⠁  ⢀⣾⠋⠁    
      ⠈⠉⠉⠙⠿⢿⣿⣇  ⠈⢿⣧⣄   ⢹⣷⣶⣶⣾⣿⡇  ⣀⣴⡿⣧⣄⡀    
            ⠙⢿⣷⡀  ⠙⢿⣿⣶⣤⡀⠻⢤⣀⡤⠞⢀⣴⣿⣿⠟⢷⡀⠙⠻⣦⣄  
              ⠈⢻⣦ ⢠⡟⠁⠙⢻⣿⠷⠶⣶⠶⠾⠛⠙⣿⠇  ⢻⡄  ⠙⢷⡀
               ⣸⣿⡀⣿⠁⣤⣤⡄⢻⡶⠶⠛⠛⠛⠛⠛⣿⢠⣾⣷⣆⢻⡀  ⠈⣷
               ⣿⣿⣿⣿⢸⣿⣿⣿⡈⢿⡀     ⡿⢸⣿⣿⣿⢸⡇   ⡟
               ⠈⠉⠉⠉⠈⠉⠉⠉⠁⠈⠁    ⠈⠁⠈⠉⠉⠉ ⠁  ⠈⠁
"""

images["mandalorian"] = r"""
Como deve ser
                     ⢀⣀⣀⣀⣀                        
                 ⢀⣠⠴⠚⣹⠁⣶⢲⢈⠉⠓⠶⢤⡀                   
               ⣠⠞⠉ ⢀⣾⢻ ⣿⡈⢸    ⠉⠳⢄⡀                
             ⢠⠞    ⣈⣿⣾⣾⣿⡇⢸       ⠙⢄               
           ⢀⡴⠃ ⢀⡀ ⣴⣿⡏⣿⣿⣿⡇⣼⡇       ⠈⠳⣄⡀            
       ⣠⡴⠶⠟⠋  ⡄⢸⡇⢸⣿⣼⣧⣿⣿⣿⣁⣿⣤⣄⣀⣀ ⢀    ⠈⠙⠛⠒⠦⠄        
            ⣠⣦⣷⣾⡿⠿⢿⣿⣿⣿⣿⣿⣿⣽⣿⣿⣿⣿⣓⣲⠲⠦⢤⣀              
          ⢀⣴⣿⣫⣭⣼⣶⣿⠿⢻⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣟⣿⣟⢻⣶⣌⢻⣶            
         ⢀⣿⡿⡿⢿⠓⠒⣛⠻⣿⣟⣿⣿⣿⣿⣿⣿⡏⠙⠋⠛    ⠈⠉⣿⢹⡆           
         ⠸⣿⡇⢀⣀  ⣿⢀ ⠸⣿⣿⣿⣿⣿⣿⠁     ⣠⣴⣶⣦⣼⣿⣇           
         ⠈⣿⡇⣿⣿⣿⣦⡹⣆  ⣿⣿⣿⣿⣿⣿   ⣴⣿⣾⣿⣿⢿⣿⣿⣿⠛           
          ⢘⣿⣿⣿⣿⣿⣿⡝⣧ ⢹⣿⣿⣿⣿⣿ ⢀⣼⣿⣿⣿⣿⣿⣿⠃⣿⣿            
          ⠈⢻⣿⢸⣿⣿⣿⣿⣿⡇⢸⣿⣿⣿⣿⡗⠈⣼⣿⢿⣿⡿⠿⢿⣯ ⠿⣿            
           ⢸⣿⣸⡇⠈⠙⢿⣷⢿⡘⣿⣿⣿⣿⠃⢠⣿⣿⡿⠉   ⢻⡀⢀⣿            
           ⢸⣿⣿   ⠈⢻⡟⣇⣇⣿⣿⣿ ⢸⣿⡿⠁     ⢷⣄⢻            
           ⢸⣿⡏     ⣿⢿⣿⣿⣿⣿ ⣾⣿⠃      ⠘⣿⡟            
           ⠘⠻⠧⣄⡀   ⢸⣾⣿⣿⣿⣿ ⣿⡟    ⣀⣠⣥⣶⣿⣦⣄⡀          
               ⠉⠙⠲⣦⣄⣿⣿⣿⣿⣿⣷⣿⣧⣴⣶⡾⣛⣯⣭⣷⠤⠶⠤⢬⣭⢽⣆⡀⢠⣶⣶⣶⠶⠶⢤
               ⣀⣀⡤⣽⣿⣿⣿⣿⣿⣿⣿⣿⣿⣻⣟⢿⠏⣉⣡⣤⣶⣾⠿⣿⣿⣿⣿⠛⢸⣾⡿⠛⠛⠛⠶
           ⣀⣠⣤⣿⣛⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣯⣿⣷⣿⣿⡿⢟⣿⡟⣰⣾⠋     
       ⣠⣴⡶⣫⣽⢿⣯⣽⣿⣿⣿⣿⠿⠛⠁⢈⣹⣿⣿⣿⣿⣿⣿⣿⠿⠿⠿⠿⠿⠿⣤⣴⣿⠛⢰⣿⠇      
      ⣰⣿⣿⣼⣟⣽⣼⣿⣿⣿⣿⣯⣷⢍⣣⣶⣿⣿⣿⣿⣿⣿⣿⠟⠁     ⢸⣿⣿⡟ ⣧⣿ ⡀     
"""


images["minion"] = r"""
Bananaaaa!
              ⣀ ⠤⠤⠤ ⣀       
           ⡠⠐⢉⠴⣚⠉⣙⠢⢄⡤⢞⡂⢀⣐⢄  
          ⡔⡤⣞⢁⠊⢀⣀⠐⢿⡄⠰⢁⡀⠈⠺⣦⢡ 
         ⢰⣿⣗⣟⡸ ⠻⡿⠃⢸⣇⢃⠿⠿  ⣽⢸ 
         ⠁ ⠈⠙⢷⣴⡀ ⠠⣪⣾⣷⡄⡀⠠⣐⢕⠁ 
 ⢰⡦      ⡇    ⠙⠲⡖⠓⠉⠁⠈⠉⠒ ⠈⢸  
⢶⣿⣷⣤⢀⣀⡀  ⣏⡑⠢⢄   ⠈⠐ ⠐     ⡸⡀ 
⠛⠛⠛⠟ ⠤⠤⠌⢉ ⠈⠓⢬⣿⣦⡤⣤⣤⠤⠤⣤⣤⣤⣤⣚⣔⣄ 
         ⡇  ⡤⠂  ⢀⠤⠤⢄⡨⠔⠒⢍⠉⢁⣯⡆
         ⡗⢤⡤⣬   ⢇   ⠁  ⡸⢰⣿⣿⡿
         ⠘⢌⡿⣽⡀  ⠈⠒⢄⡀ ⢀⠔⠁⠈⠙⡋ 
           ⠑⠳⢧⣠⣤⣄⣠⣀⣈⣱⡥⠤⠴⠦⠴⠃ 
              ⢹⣿⣿ ⣿⣿⣿⣄      
              ⠙⠉⠉ ⠈⠉⠉⠉      
"""

images["minions2"] = r"""
Banana banana bananáaaaaa!
            ⣀⢀⣠⣤⣄⡀⢀⣀          
         ⣠⡶⠛⢉⠤⣀⠤⡠⢫⠵⠶⢩⡢        
 ⣀      ⢰⠋ ⣠⢡⠋⠉⠙⣆⢂⣤⡄⠈⡇⡇  ⣀⣶⣄⢤ 
⢠⢇⠓⠒⣂⡤⡀ ⡆ ⡜⣿⣜⢄⣿⢆⠜⣤⣝⣓⣢⠜ ⡠⢛⠧⠬⠭⠸⠇
⠈⠒⠓⠂⠙⠓⢌⠢⢷⡫⠐⠉⠛⠴⠶⠖⠊ ⠉⠉ ⢸⠌⡰⠁     
       ⠑⡀⠙⢕⢦  ⠠⣲⣒⠲⢲⠎⢻⢈⣷       
        ⠸⡀ ⢣⡑⡄ ⠑⠠⠄⠘⠴⠂⣸⣹       
         ⠃  ⢹⣼⡶⣄    ⡴⢿⢻       
         ⢀   ⡝⠁ ⠙⠒⠒⠋ ⢸⢸       
         ⢸⢄⣀⣀⡇  ⡖⢦⣴⠊⡆⢸⣸       
         ⢰ ⠉⢸⠁ ⠸⡇⣞⣯⡷⡇⢨⢹       
         ⣸⡀⠔⠃   ⠑⠬⠭⠝ ⣈⡾⡄      
        ⡴⢣⠑⢄⣀⣀⣀⣀⣀ ⠤⣐⢞⣿⡡⠃      
        ⠈⠁⠉⠉       ⠈⠫⠙        
"""

images["slayer"] = r"""
Não há atalhos, apenas trabalho duro.
Treine duro e seja paciente. Vai valer a pena.
⠏⠁⠈⠙⠛⢿⣿⣿⣿⣿⣿⣿⣿⡟ ⠈⠻⣿⣿⣿⣿⣿⠟⢡⡿⢿⣿⠿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿
    ⢀⣎⣏⡏⣟⠛⠿⠿⡟⢁⣀⣀⣠⡼⠟⠛⠉  ⠉⠐⠋  ⠛⠋⠭⠾⢿⣿⣿⠟⣫⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿
⣦⣶⡀   ⠉⠛⣿⣿⣷⣿⣇⣠⠟⠋⠁  ⢀⡄       ⣀⣠⡤⠴⠒⠋⠁⣰⡿⢿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿
⣿⣿⣷  ⡀   ⠉⠉⡿⠋⠁⡠⢀⠄⡠⠔⠋⢀⣀⠔ ⢀⡤⠚⣽⡟⠋   ⢀⡜⢱⠃⠉⣩⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿
⣿⣿⣿⣦⡀⢹   ⢀⡞⠁⡰⠛⣡⢃⣾⠁⠤⡾⢋⣀⡀⠠⠊ ⢾⣏⡾ ⢀⣠⡴⠿⠙⣿⠃ ⠙⠛⢉⣿⣿⣿⣿⣿⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣷⡄  ⡜ ⠐⡅⡜⡇⢠⠃⡠⠊⠐⠝⠋    ⠈⠙⢁⠔⣯⡝⢁⡶⢾⣿⠇   ⠐⠺⠿⢻⣿⣿⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⡀⣠⡇ ⣠⡇⡸ ⢣⠎⢀⣀⣤⣴⣶⠟⠛      ⣭⣷⣤⡴⠋        ⠙⣽⡿⢿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⣿⢿⡇⢀⡟⠃⣡⡿⠃⣰⣾⡯⠚⠉⣀⣠⣄⣤            ⢀ ⢀⡈⠁   ⣠⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣿⡇⢸⣷⠸⠁⢲⡏⢀⣾⣿⠏⣠⠞⠁ ⢾⣿⣽⡆⡀ ⣠        ⣀⡠⠄   ⢀⡾⢧⣿⣿⣿⣿
⣿⣿⣿⣿⣿⣿⣟⣳⣿⣿⣆ ⢸⠁⠸⣿⠏⣰⣿ ⡀  ⢁⣻⣧⣷⣿⡽⠃      ⠉    ⢠⣶⠯⣄⣠⡽⠿⢿⣿
⣿⣿⣿⣿⣿⣿⣟⡁⢈⠟⣁    ⠋⢰⣿⡿⣧⣌⣒⣒⣿⣞⣿⣿⠋           ⢀⣸⣯⠽⠋⠁     
⣿⣿⣿⠿⣿⣿⡿⠟⠁⠊⠱⣣⣶⡀  ⢘⡛⠓⠚⣛⣋⣛⣸⠭⠞⠁          ⣀⡠⣞⡋⠁        
⣿⣿⡃ ⠘⣿⢤⡀   ⣹⣿⡟ ⢀⡎⢱ ⡀                ⣉⡥⠖⠉          
⣿⣟⢿ ⢆⠘⢦⡈⢦⡠⡺⠋⠉⠠⢊⡝ ⢰⣧⡈⠓⢤⣀             ⣽⠶⠄           
⣿⣿⣼⣷⠈⢳⣄⠙⠲⣧  ⣠⠖⠋⠙⠢⠼⠁⠙⠶ ⠈⠉⠛⠤         ⣀⠉⠉            
⣿⣿⣷⣍  ⠻⠷⠄⢘⣧⣞⣡⣶⣏⠉⣳ ⣠⣤⣀ ⢤⣠⡐⠦⣄⡀    ⢀⡐⠒⠉              
⣿⣿⣿⣿⣿⣷⣶⣄⣀⣸⣿⣿⣿⣿⣿⣶⣿⣆⣻⣿⣿⣷⣶⢭⣿⣦⣶⠿⠾⣗⢒⠿ ⠁                
⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡌⠁⠙⠂⢀⡉⣁⡠⠴⠛⠉⠁                  
⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣦⣀  ⠈ ⣄              ⣠⣤⣶⠶⠖⣶⠁ 
⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣛⡦ ⣀⣨⠟⠲⠤⠤⠬⣷⣀          ⣠⣴⠟⢁⡀ ⣼⠇  
⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣧⣶⣬⣿⣿⣡⣵⣖⣤⣀⣤⣈⣙⣶⣦⣤⣀⣀⣠⡤⠶⠟⠋⠁  ⠉⢷⠉   
"""

images["jujutsu"] = r"""
Não sei como vou me sentir quando estiver morto, 
mas não quero me arrepender da maneira como vivi.
   ⣀                      
⢠⣀⡀⡏⠳⣄   ⢀⡀ ⢠             
⡤⠵ ⢀⡶⠛⠁⢢⢄⡜⠱⡾⠍⠧⠲⡇⣀⡄        
⠈⢶⣤⠛⠁⣀⡹⠉        ⠰⠥⣤       
  ⠁ ⠠⣿⢃⢀⣤⣤⡴⣰⢰⣠⢠  ⢨⣷⡆      
     ⠝⢿⠙⢯⣟ ⣱⡿⠌⡷⣿⣾⣿⡿⠙⢦     
      ⣸ ⠼   ⠃⣠⠄⠘⡟⢘⣄ ⠈⢷    
     ⠘⡏⠉ ⡐⢢ ⢀⡀ ⢰⠖⡩⠊ ⣠⠋    
      ⢈⣷⢄⡑⠚⢀⡠⠤⣒⠡⠊⢀⣠⣾⣿⣦    
    ⢀⣴⣿⣿⣿⣍⠫⠇⠐⠉⢒⣠⣴⣿⣿⣿⣿⣿⡆   
  ⡤⢐⠚⣿⣿⣿⣿⣿⣶⣶⣶⣶⣾⣿⣛⠟⠛⣿⣿⣿⡇   
 ⢸⠐⠠⢌⣺⣿⠿⠛⠻⣿⣿⣿⣿⣿⣿ ⠄ ⠈⣿⣿⣷   
  ⠣⢌⡹⠋⠁ ⢀⣠⣿⣿⣿⣿⣿⣿⣯⣭⣀⣴⣿⣿⣿⠇  
     ⢀⣠⣶⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣍   
   ⢠⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣇  
  ⢀⣾⣿⣿⣿⣿⣿⡿⠏⠁ ⠈⠉⠙⢿⣿⣿⣿⣿⣿⣿⣿⣇ 
  ⣼⣿⣿⣿⣿⡿⠋⠁       ⠙⢿⣿⣿⣿⣿⣿⣿⡆
 ⠘⠛⣿⡿⠛⠋              ⢿⣿⣏⠉⠉
⢀⠤⣾⠛⣿                ⠾⣐⣚⣦ 
⠉⠉⠉⠉⠁                     
"""


images["gollum"] = r"""
        Meu precioso!         
        ⣀⣠⣴⣶⡿⠟⠋⠁              
     ⢀⣴⣾⣿⣿⣿⠋      ⠈           
   ⢀⣼⡿⠛⠻⣿⣿⠃⢀            ⢀     
  ⢠⣿⣿⠃⢰⣆⠘⢿⡦⠈            ⠸     
 ⢠⣿⣿⣿ ⠙⢿⡆⠈⠁                 ⡀ 
⢀⣿⣿⣿⣿⢀⠐⢿⠃                  ⢀⣷ 
⠈⠉⠉⠙⠛⠃⣷⣮⠃ ⢀⣀⣀⡀             ⢸⣿⡇
      ⠘⣿⡄⠐⠚⢆⠁⠙⢻⣶⣦⣄⡀⡀       ⠘⠋⠁
  ⢀⣶⡀⠐⣠⣿⣷⣤⡀⠐⠙⠶⠶⠿⠿⠛⠿⣿⣿⣿⣤⣴⣀  ⣴⢎ 
  ⠈⣿⣿⣾⣿⣿⣿⣿⣇⣠⠴⠖⠲⡂   ⠹⣿⣟⡛⠹⠛⠂⠘⣡⡿ 
   ⢻⣿⣿⣿⣿⣿⡇⢹⣧   ⠱⢀⣀⡠⠲⣄⣹⣿⡏ ⣠⣾⣿⠃ 
   ⠸⣿⣿⣿⣿⣿⡇ ⠁⠙⣢⣄⣀    ⢹⣿⣿⣫⣾⣿⡿⠃  
    ⠙⢩⢻⣿⣿⣷⡀  ⢈⡙⠛⠿⠓⠐⠉ ⢸⣿⣿⣿⠟⠁   
       ⠽⢀⣤⡀ ⢠⣤⡈⠉⠁⠠⠤  ⠘⠿⠋⠁     
         ⠉⠛⠿⠶⢾⣭⢤⡾ ⠠⠒          
"""

images["mickey"] = r"""
             .-'''-.                                      
            /       \                                     
            \       /                                     
     .-'''-.-`.-.-.<  _                                   
    /      _,-\ O_O-_/ )  Se você pode sonhar, pode fazer!
    \     / ,  `   . `|                                   
     '-..-| \-.,__~ ~ /          .,                       
           \ `-.__/  /          /"/                       
          / `-.__.-\`-._    ,",' ;                        
         / /|    ___\-._`-.; /  ./-.                      
        ( ( |.-"`   `'\ '-( /  //.-'                      
         \ \/    {}{}  |   /-. /.-'                       
          \|           /   '..'                           
           \        , /                                   
           ( __`;-;'__`)                                  
           `//'`   `||`                                   
          _//       ||                                    
  .-"-._,(__)     .(__).-""-.                             
 /          \    /           \                            
 \          /    \           /                            
  `'-------`      `--------'`                             
"""


images["homer1"] = r"""
                         (####)                                              
                        (#######)                                            
                      (#########)                                            
Normalmente eu não sou um homem de rezas, mas se você está aí em cima,       
por favor me salve, Super-Homem!" (Homer Simpson)                            
                   (#########)                                               
   __&__          (#########)                                                
  /     \        (#########)   |\/\/\/|     /\ /\  /\               /\       
 |       |      (#########)    |      |     | V  \/  \---.    .----/  \----. 
 |  (o)(o)       (o)(o)(##)    |      |      \_        /       \          /  
 C   .---_)    ,_C     (##)    | (o)(o)       (o)(o)  <__.   .--\ (o)(o) /__.
  | |.___|    /___,   (##)     C      _)     _C         /     \     ()     / 
  |  \__/       \     (#)       | ,___|     /____,   )  \      >   (C_)   <  
  /_____\        |    |         |   /         \     /----'    /___\____/___\ 
 /_____/ \       OOOOOO        /____\          ooooo             /|    |\    
/         \     /      \      /      \        /     \           /        \   
"""

images["homer2"] = r"""
    ___     Existem três jeitos de fazer as coisas: o jeito certo, 
   //_\\_   o jeito errado, e o meu jeito – que é igual ao jeito   
 ."\\    ". errado, só que mais rápido (Homer Simpson)             
/          \                                                       
|           \_                                                     
|       ,--.-.)                                                    
 \     /  o \o\                                                    
 /\/\  \    /_/                                                    
  (_.   `--'__)                                                    
   |     .-'  \                                                    
   |  .-'.     )                                                   
   | (  _/--.-'                                                    
   |  `.___.'                                                      
         (                                                         
"""

images["mine"] = r"""
Isso é um bloco de código?   
      ⢀⡠⢴  ⠠⠤⠤⠤⠤⢤            
      ⡇ ⢸    ⡖⠂⢠⢸            
      ⡇ ⢸ ⡶⡾⡍ ⠤⣤⣸            
      ⡇ ⢸ ⠉⠉⣁⣀⠉⢉⢸            
   ⢀⡴ ⠧⢤⡼⠤⠦⠤⠭⠭⢤⣼⣼⣀⣠⣀⡤⠒⠲⡋⣷⡄   
  ⢀⡾⢸  ⢸⡇ ⠐⠳ ⡐⠙⢸⡏⣀⣼⣇⢀⣤⡶⢯ ⠙⣦  
 ⢀⠎⢸⣊⣀⡀⡽⣇⡀⢀    ⢸⡟⢂ ⠈⠉⡟⣐⢺⣧ ⣹⡆ 
⢠⠋⠠⠃  ⡼  ⠁⠊    ⢸⣇ ⠑⢄⡾⢠⢻⢏ ⠋⠚⠃ 
⢸⡴⠁ ⢀⡞⢠        ⢸⠌⠣⡀⡼⠡⡁⡟⠓⡇    
 ⠁ ⠒⠊ ⢸⢤⣀⣀⣀⣀   ⢸⡆ ⢹⠁⡜⣼⣀⠼     
      ⠈⣶⠒⠒⠒⢲⠒⠒⠒⢺   ⠉⠉        
       ⣿   ⠸⣇⣀⣀⡈⡆            
       ⢻⡇   ⡇  ⢰⠁            
       ⢸⢁   ⠃ ⢀⠇             
       ⠈⢸   ⢸⠤⠜              
        ⡟⣍⣉⣉⣙⡀               
        ⠷⠤⠤⠤⠜                
"""

images["hkitty"] = r"""
           Que código fofo, gamei.           
                        ⢀⣀⣤⣀⡀   ⡀⢀⣠⣀⡄        
      ⢀⣵⡶⢶⣶⣦⣄⣠  ⡀     ⢀⣠⣾⣿⢿⡿⣿⣦⣤⣶⡿⠟⠛⠛⢿⣆⠄      
     ⣀⣿⠋   ⠈⠙⠻⠿⣿⠿⠿⠿⠿⠿⠿⣿⣿⡿⣯⢿⣽⣻⢿⣿⠁    ⠈⣿⣀      
     ⢺⡟              ⢠⣿⣿⣽⢻⣿⣿⣿⣿⣿⣿⣶⣦⢠⣤⣤⣿⣯      
     ⣸⣇              ⢸⣿⣷⣻⢿⣿⣿⣿⡿⣯⣟⡿⣿⣿⣿⢿⡿⣿⣷⡀    
     ⠙⣿⡾⠂            ⠈⢿⣾⣯⣟⣿⣿⣿⣽⣷⣻⣽⣿⣿⣿⣿⣻⣽⣿⠁    
     ⣰⡿⠁               ⠉⠛⠛⠉⠉⠙⠿⠾⠿⣾⣿⣿⣿⡿⣽⣾⢏⠁    
    ⢤⣿⠁                         ⠙⢿⣿⣾⣽⡿⣿⣀     
    ⣾⡇                            ⠉⠉⠉ ⢻⡇     
⣀⣀⣄⣀⣿⣇⣀⡀                            ⣤⡴⣾⣿⡶⢶⡶⢆ 
⠚⠉⠉⠙⢻⡏⠉⠉   ⢠⣿⣿⡄              ⢰⣿⣷      ⢸⡇⠂    
   ⢠⣺⣿⣤⣤   ⠈⠻⠟      ⣀⣤⣤⣄     ⠘⠻⠋    ⠐⢳⣿⠷⡾⠦⠔  
  ⠘⠋⠙⠹⣷⡀            ⢿⣄⣠⡿           ⣀⣀⣼⣏      
      ⣸⣿⣿⠏                         ⢈⣿⣿⣿⣎⡀    
   ⢠⣴⠿⠋⠉⠙⢿⣦⣄⡀                   ⢀⣠⣴⢿⠏  ⠈⠙⠃   
   ⠈      ⠈⠹⣻⣷⣶⣤⣤⣤⣀⣀⣀⣀⣀⣀⣀⣀⣀⣤⣤⣤⣶⣾⠟⡫⠁          
        ⡀⢀⣴⡾⠛⣹⣿⣿⣿⣿⣿⠉⠉⠉⠉⠉⠉⢩⣿⣿⣿⣿⣯⠙⠻⣾⣄          
     ⢀⣨⡾⠟⠟⠻⣷⣴⣿⣿⣿⣟⣿⣿⣧⣀  ⢀⣠⣿⣿⣿⣟⣿⣿⣧⣴⡿⠛⠻⢷⣆⠄      
     ⢠⢿⡅   ⢸⣿⣿⣿⣟⣾⣿⣻⣿⣿⣿⣿⣿⣿⣿⣿⣯⣿⣟⣿⣿⡇   ⢠⣿       
     ⠈⣿⡇   ⣾⣿⣿⢿⣾⣿⣽⡿⣯⣿⣟⣿⣿⣻⣿⣾⣟⣷⣿⣟⣿⣷   ⢸⣿⡀      
      ⠘⢿⣦⣀⣸⣿⣿⡿⣿⣻⣾⣟⣿⣿⣽⣿⣻⣾⡿⣷⣿⣻⣿⣾⢿⣻⣿⣧⣠⣴⡿⠃       
        ⠘⠉⢿⣿⣿⢿⣟⣿⣽⣿⣻⣾⢿⣾⣿⣷⣿⢿⣽⣿⣳⣿⡿⣿⣿⣿⠍⠁⠁        
         ⠘⣿⡟⠿⠿⠿⢿⣿⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠿⠿⠿⠿⢿⣿⠄          
         ⠠⣿⡇         ⢠⣿         ⢸⣿⠄          
          ⠼⣷⡄        ⠐⣿        ⢀⣾⠧           
           ⠈⠻⢷⣦⣤⣤⣀⣤⣤⣤⣼⣿⣦⣤⣤⣠⣤⣤⣴⡶⠟⠁⠁           
             ⠈ ⠈⠉⠉⠉⠉⠁   ⠉⠉⠉⠉  ⠁              
"""

images["pickaxe"] = r"""
Melhor minerar bitcoin!       
         ⢰⣶⣶⣶⣶⣶⣶⣶⣶⣶⣶⡆         
       ⢰⣶⡎⠉⠉⠉⠉⠉⠉⠉⠉⠉⠉⢱⣶⣶⣶⣶⣶⣶⡆  
       ⠘⠛⢣⣤⣤⣤⣤⣤⣤⣤⣤⡄ ⠈⠛⠛⠛⠛⣿⣿⡇  
         ⠘⠛⠛⠛⠛⠛⠛⠛⠛⢣⣤⡄    ⣿⣿⡇  
                ⣀⣀⡸⠿⢇⣀⣀  ⠻⠿⢃⣀⡀
              ⣀⣀⠿⠿⢇⣀⡸⠿⠿⣀⣀  ⢸⣿⡇
              ⣿⣿  ⢸⣿⡇  ⣿⣿  ⢸⣿⡇
            ⣿⣿  ⣿⣿⡇    ⣿⣿  ⢸⣿⡇
         ⢸⣿⡇  ⣿⣿       ⣿⣿  ⢸⣿⡇
       ⢰⣶⡎⠉⠱⣶⣶⠉⠉       ⣿⣿  ⢸⣿⡇
     ⣶⣶⡌⠉⢱⣶⡆⠉⠉         ⠉⠉⣴⣶⡎⠉⠁
   ⣤⣤⠛⠛⢡⣤⡜⠛⠃             ⠛⠛⠃  
⢀⣤⣤⠛⠛⣤⣤⡘⠛⠃                    
⢸⣿⣿⣀⣀⠿⠿⠃                      
⠸⠿⠿⠿⠿                         
"""


images["feio"] = r"""
Esse código é tão feio!     
          ⢀⡠⠤⠖⢒⠂⢤⣀          
 ⢀⣀     ⢠⠖⠁      ⠢⣥⣢     ⣠⣤ 
⢀⣟⣿⣦   ⣰⡿⠿⠷⠶⣄  ⢠⠾⠟⠛⠛⢷⡀ ⢀⡼⣿⣇⡇
⠈⠛⠛⠿⢕⡂⢴⠁   ⢀⠈⠆⠠⣮⣴⢤⡀⣀⣸⣗⣶⡧⠒⠉⠉⠁
     ⢹  ⠴⣺⣿⣿⠇  ⠛⡿⣽⣿⣽⠿⠛⢻     
     ⡌  ⠈⠉⢩     ⣸⣒⣄    ⠇    
     ⡇ ⢀⡴⠖⠉⠛⠓⠲⠶⠾⠿⠿⠿⢏⡳⡀⠄⣾    
     ⠃ ⠞ ⣀⣀⣀⣀⣀⣀⣀⣤⣤⣶⣿⣇⢧ ⣿    
     ⡄   ⠈⠫⢽⣽⣉⣹⣁⣧⣿⠟⣱⣿⣾⢀⣿    
     ⢃      ⠉⠙⠩⠤⠭⣶⣋⡟⢸⢁⣿⠏    
      ⠱⡀        ⠈⠛⠝⡇⣘⡾⠋     
       ⠈⠢⣀       ⣠⣴⣷⠋       
          ⠑⠠⠤⠤⠤⠤⠾⠟⠋⠁        
"""

images["riso"] = r"""
      ⢀⣤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⢤⣤⣀⣀⡀      
    ⢀⡼⠋ ⣀⠄⡂⠍⣀⣒⣒⠂ ⠬⠤⠤⠬⠍⠉⠝⠲⣄⡀  
   ⢀⡾⠁ ⠊⢔⠕⠈⣀⣀⡀⠈⠆   ⡍⠁ ⠁⢂ ⠈⣷  
  ⣠⣾⠥  ⣠⢠⣞⣿⣿⣿⣉⠳⣄  ⣀⣤⣶⣶⣶⡄  ⣘⢦⡀
⢀⡞⡍⣠⠞⢋⡛⠶⠤⣤⠴⠚ ⠈⠙⠁  ⢹⡏⠁ ⣀⣠⠤⢤⡕⠱⣷
⠘⡇⠇⣯⠤⢾⡙⠲⢤⣀⡀⠤ ⢲⡖⣂⣀  ⢙⣶⣄⠈⠉⣸⡄⠠⣠⡿
 ⠹⣜⡪ ⠈⢷⣦⣬⣏⠉⠛⠲⣮⣧⣁⣀⣀⠶⠞⢁⣀⣨⢶⢿⣧⠉⡼⠁
  ⠈⢷⡀  ⠳⣌⡟⠻⠷⣶⣧⣀⣀⣹⣉⣉⣿⣉⣉⣇⣼⣾⣿ ⡇ 
   ⠈⢳⡄  ⠘⠳⣄⡀⡼⠈⠉⠛⡿⠿⠿⡿⠿⣿⢿⣿⣿⡇ ⡇ 
     ⠙⢦⣕⠠⣒⠌⡙⠓⠶⠤⣤⣧⣀⣸⣇⣴⣧⠾⠾⠋  ⡇ 
       ⠈⠙⠶⣭⣒⠩⠖⢠⣤⠄     ⠠⠔⠁⡰ ⣧ 
           ⠉⠛⠲⢤⣀⣀⠉⠉     ⠁ ⣠⠏ 
               ⠈⠉⠉⠛⠒⠲⠶⠤⠴⠒⠚⠁  
"""
